@@ -60,12 +60,15 @@ class Api:
         self.ad_units = api_client("adunits")
         self.ad_unit_tags = api_client("adunittags")
         self.advertisers = api_client("advertisers")
+        self.advertisingaccessgroups = api_client("advertisingaccessgroups")
         self.allocation_report = api_client("allocationreport")
+        self.asset = api_client("asset")
         self.available_currencies = api_client("availablecurrencies")
         self.api_keys = api_client("apikeys")
         self.simple_assets = api_client("asset")
         self.assets = api_client("assets")
         self.ax_product = api_client("axproduct")
+        self.bulkcreatives_thirdparty = api_client("bulkcreatives/thirdparty")
         self.burn_rates = api_client("burnrates")
         self.categories = api_client("categories")
         self.categories_upload = api_client("categories/upload")
@@ -76,6 +79,7 @@ class Api:
         self.creativepreviewhtml = api_client("creativepreview", accept="text/html")
         self.creatives = api_client("creatives")
         self.creative_info = api_client("creatives/info")
+        self.creative_collections = api_client("creativecollections")
         self.currency_conversion = api_client("currencyconversion")
         self.custom_event_types = api_client("customeventtypes")
         self.data_export = api_client("dataexports")
